@@ -29,6 +29,9 @@ def data_handler(request, secret):
     reference = request.POST.get('Reference', None)
     order = get_object_or_404(NetcashOrder, pk=reference)
 
+    if order.trusted: # don't process processed orders again
+        raise Http404
+
     if gateway.netcash_ip:
         # deny query if it come from untrusted ip
         if ip != gateway.netcash_ip:
